@@ -57,8 +57,8 @@ Q_LOGGING_CATEGORY(cfLog, "dtk.dsg.config");
 
     \brief 按子目录查找机制查找配置文件
 
-    在\a baseDir目录下,查找名称为\a name的文件,
-    若存在 \a subpath,则从\a subpath叶子目录逐级向上查找名称为\a name的文件,
+    在 \a baseDir目录下,查找名称为 \a name的文件,
+    若存在 \a subpath,则从 \a subpath叶子目录逐级向上查找名称为 \a name的文件,
     若不存在此文件,则返回无效路径.
  */
 inline QString getFile(const QString &baseDir, const QString &subpath, const QString &name,
@@ -180,9 +180,15 @@ inline static QString getUserName(const uint uid) {
 }
 
 /*!
-    \enum DConfigFile::Flag
+    \class Dtk::Core::DConfigFile
     \inmodule dtkcore
 
+    \brief 规范配置文件读写的相关接口的配置文件实现.
+ */
+
+/*!
+    \enum DConfigFile::Flag
+
     \value NoOverride  存在此标记时，将表明则此配置项不可被覆盖（详见下述 override 机制）。
     反之，不存在此标记时表明此配置项允许被覆盖，对于此类配置项，
     如若其有界面设置入口，则当此项不可写时，应当隐藏或禁用界面的设置入口.
@@ -192,7 +198,6 @@ inline static QString getUserName(const uint uid) {
 
 /*!
     \enum DConfigFile::Permissions
-    \inmodule dtkcore
 
     \value ReadOnly 将配置项覆盖为只读，
     \value ReadWrite 将配置项覆盖为可读可写.
@@ -200,7 +205,6 @@ inline static QString getUserName(const uint uid) {
 
 /*!
     \enum DConfigFile::Visibility
-    \inmodule dtkcore
 
     \value Private 仅限程序内部使用，
     对外不可见。此类配置项完全由程序自己读写，可随意增删改写其含义，无需做兼容性考虑，
@@ -212,9 +216,8 @@ inline static QString getUserName(const uint uid) {
 */
 
 /*!
-    \class DConfigFile::Version
+    \struct Dtk::Core::DConfigFile::Version
     \inmodule dtkcore
-
     \brief 版本信息
 
     此文件的内容格式的版本。版本号使用两位数字描述，
@@ -383,14 +386,18 @@ public:
         values.remove(key);
     }
 
-    inline void update(const QString &key, const QVariantHash &value)
+    inline bool update(const QString &key, const QVariantHash &value)
     {
+        if (!value.contains("value")) {
+            return false;
+        }
         values[key] = value;
+        return true;
     }
 
-    inline void updateValue(const QString &key, const QJsonValue &value)
+    inline bool updateValue(const QString &key, const QJsonValue &value)
     {
-        overrideValue(key, "value", value);
+        return overrideValue(key, "value", value);
     }
 
     inline void updateSerial(const QString &key, const QJsonValue &value)
@@ -412,11 +419,15 @@ public:
         return contents;
     }
 private:
-    void overrideValue(const QString &key, const QString &subkey, const QJsonValue &from) {
+    bool overrideValue(const QString &key, const QString &subkey, const QJsonValue &from) {
         const QJsonValue &v = from[subkey];
 
-        if (!v.isUndefined())
-            values[key][subkey] = v.toVariant();
+        if (v.isUndefined()) {
+            return false;
+        }
+
+        values[key][subkey] = v.toVariant();
+        return true;
     }
 
     QHash<QString, QVariantHash> values;
@@ -424,17 +435,17 @@ private:
 
 
 /*!
-    \class DConfigMeta
+    \class Dtk::Core::DConfigMeta
     \inmodule dtkcore
 
-    \brief 提供配置文件的原型和覆盖机制的访问接口
+    \brief 提供配置文件的原型和覆盖机制的访问接口.
 
 */
 
 /*!
     \fn DConfigFile::Version DConfigMeta::version() const = 0;
 
-    \breaf 返回配置版本信息
+    \brief 返回配置版本信息.
     \return
 */
 
@@ -449,7 +460,7 @@ private:
 /*!
     \fn bool DConfigMeta::load(const QString &localPrefix = QString()) = 0;
 
-    \breaf 解析配置文件
+    \brief 解析配置文件
     \a localPrefix 为目录前缀
     \return
 */
@@ -457,7 +468,7 @@ private:
 /*!
     \fn bool DConfigMeta::load(QIODevice *meta, const QList<QIODevice*> &overrides) = 0;
 
-    \breaf 解析配置文件流
+    \brief 解析配置文件流
     \a meta 为原型流
     \a overrides 为覆盖机制查找的文件流
     \return
@@ -466,14 +477,14 @@ private:
 /*!
     \fn QStringList DConfigMeta::keyList() const = 0;
 
-    \breaf 返回配置内容的所有配置项
+    \brief 返回配置内容的所有配置项
     \return
 */
 
 /*!
     \fn DConfigFile::Flags DConfigMeta::flags(const QString &key) const = 0;
 
-    \breaf 返回指定配置项的特性
+    \brief 返回指定配置项的特性
     \a key 配置项名称, NoOverride为此配置项不可被覆盖, Global为忽略用户身份
     \return
 */
@@ -481,7 +492,7 @@ private:
 /*!
     \fn DConfigFile::Permissions DConfigMeta::permissions(const QString &key) const = 0;
 
-    \breaf 返回指定配置项的权限
+    \brief 返回指定配置项的权限
     \a key 配置项名称
     \return
 
@@ -490,7 +501,7 @@ private:
 /*!
     \fn DConfigFile::Visibility DConfigMeta::visibility(const QString &key) const = 0;
 
-    \breaf 返回指定配置项的可见性
+    \brief 返回指定配置项的可见性
     \a key 配置项名称
     \return
 
@@ -499,7 +510,7 @@ private:
 /*!
     \fn int DConfigMeta::serial(const QString &key) const = 0;
 
-    \breaf 返回配置项的单调递增值
+    \brief 返回配置项的单调递增值
     \a key 配置项名称
     \return -1为无效值，表明没有配置此项
 */
@@ -507,7 +518,7 @@ private:
 /*!
     \fn QString DConfigMeta::displayName(const QString &key, const QLocale &locale) = 0;
 
-    \breaf 返回指定配置项的显示名
+    \brief 返回指定配置项的显示名
     \a key 配置项名称
     \a locale 为语言版本
     \return
@@ -516,7 +527,7 @@ private:
 /*!
     \fn QString DConfigMeta::description(const QString &key, const QLocale &locale) = 0;
 
-    \breaf 返回指定配置项的描述信息
+    \brief 返回指定配置项的描述信息
     \a key 配置项名称
     \a locale 为语言版本
     \return
@@ -526,7 +537,7 @@ private:
 /*!
     \fn QString DConfigMeta::metaPath(const QString &localPrefix = QString(), bool *useAppId = nullptr) const = 0;
 
-    \breaf 返回描述文件的路径
+    \brief 返回描述文件的路径
     \a localPrefix 目录的所有需要查找的覆盖机制目录
     \return
 */
@@ -534,7 +545,7 @@ private:
 /*!
     \fn QStringList DConfigMeta::allOverrideDirs(const bool useAppId, const QString &prefix = QString()) const = 0;
 
-    \breaf 获得前缀为\a prefix目录的所有需要查找的覆盖机制目录
+    \brief 获得前缀为 \a prefix 目录的所有需要查找的覆盖机制目录
     \a userAppId 是否不使用通用目录
     \return
 */
@@ -542,7 +553,7 @@ private:
 /*!
     \fn QVariant DConfigMeta::value(const QString &key) const = 0;
 
-    \breaf meta初始值经过覆盖机制覆盖后的原始值
+    \brief meta初始值经过覆盖机制覆盖后的原始值
     \a key 配置项名称
     \return
 */
@@ -595,30 +606,46 @@ public:
         return values.value(key);
     }
 
-    inline QString applicationMetaDir(const QString &prefix, const bool useOptDir = false) const
+    inline QStringList applicationMetaDirs(const QString &prefix) const
     {
-        if (useOptDir)
-            return QString("%1/opt/apps/%2/files/schemas/configs").arg(prefix, configKey.appId);
-
-        return QString("%1/usr/share/dsg/apps/%2/configs").arg(prefix, configKey.appId);
+        QStringList paths;
+        // lower priority is higher.
+        const auto &dataPaths = DStandardPaths::paths(DStandardPaths::DSG::DataDir);
+        paths.reserve(dataPaths.size());
+        for (auto item : dataPaths) {
+            paths.prepend(QString("%1/%2/configs/%3").arg(prefix, item, configKey.appId));
+        }
+        return paths;
     }
 
-    inline static QString genericMetaDir(const QString &prefix) {
-        return prefix + DStandardPaths::filePath(DStandardPaths::DSG::DataDir,
-                                                 QString("configs"));
+    inline static QStringList genericMetaDirs(const QString &prefix) {
+        QStringList paths;
+        for (auto item: DStandardPaths::paths(DStandardPaths::DSG::DataDir)) {
+            paths.prepend(QString("%1/%2/configs").arg(prefix, item));
+        }
+        return paths;
     }
 
     QString metaPath(const QString &localPrefix, bool *useAppId) const override
     {
         bool useAppIdForOverride = true;
 
-        QString path = getFile(applicationMetaDir(localPrefix), configKey.subpath, configKey.fileName + FILE_SUFFIX);
-        if (path.isEmpty())
-            path = getFile(applicationMetaDir(localPrefix, true), configKey.subpath, configKey.fileName + FILE_SUFFIX);
+        QString path;
+        const QStringList &applicationMetas = applicationMetaDirs(localPrefix);
+        for (auto iter = applicationMetas.rbegin(); iter != applicationMetas.rend(); iter++) {
+            path = getFile(*iter, configKey.subpath, configKey.fileName + FILE_SUFFIX);
+            if (!path.isEmpty())
+                break;
+        }
 
         if (path.isEmpty()) {
             useAppIdForOverride = false;
-            path = getFile(genericMetaDir(localPrefix), configKey.subpath, configKey.fileName + FILE_SUFFIX);
+            const QStringList &genericnMetas = genericMetaDirs(localPrefix);
+            for (auto iter = genericnMetas.rbegin(); iter != genericnMetas.rend(); iter++) {
+                path = getFile(*iter, configKey.subpath, configKey.fileName + FILE_SUFFIX);
+                if (!path.isEmpty())
+                    break;
+            }
         }
         if (useAppId) {
             *useAppId = useAppIdForOverride;
@@ -679,14 +706,15 @@ public:
 
             // 初始化原始值
             for (; i != contents.constEnd(); ++i) {
-                values.update(i.key(), i.value().toObject().toVariantHash());
+                if (!values.update(i.key(), i.value().toObject().toVariantHash())) {
+                    qWarning() << "key:" << i.key() << "has no value";
+                    return false;
+                }
             }
         }
-
         // for override
         Q_FOREACH(auto override, overrides) {
             const QJsonDocument &doc = loadJsonFile(override);
-
             if (doc.isObject()) {
                 const QJsonObject &root = doc.object();
                 if (!checkMagic(root, MAGIC_OVERRIDE)) {
@@ -715,7 +743,10 @@ public:
                     if (values.flags(i.key()) & DConfigFile::NoOverride)
                         continue;
 
-                    values.updateValue(i.key(), i.value());
+                    if (!values.updateValue(i.key(), i.value())) {
+                        qWarning() << "key (override):" << i.key() << "has no value";
+                        return false;
+                    }
                     values.updateSerial(i.key(), i.value());
                     values.updatePermissions(i.key(), i.value());
                 }
@@ -733,12 +764,17 @@ public:
         const QString &path2 = QString("%1/etc/dsg/configs/overrides/%2/%3")
                 .arg(prefix, useAppId ? configKey.appId : QString(), configKey.fileName);
 
-        const QString &path1 = QString("%1%2/configs/overrides/%3/%4")
-                .arg(prefix, DStandardPaths::path(DStandardPaths::DSG::DataDir),
-                     useAppId ? configKey.appId : QString(), configKey.fileName);
-
+        QStringList paths;
+        const QStringList &dataPaths = DStandardPaths::paths(DStandardPaths::DSG::DataDir);
+        paths.reserve(dataPaths.size() + 1);
+        for (auto path: dataPaths) {
+            // reverse `DataDir`'s paths, previous `DataDir`'s value has high priority
+            paths.prepend(QString("%1%2/configs/overrides/%3/%4")
+                          .arg(prefix, path, useAppId ? configKey.appId : QString(), configKey.fileName));
+        }
         // 在后面的优先级更高
-        return {path1, path2};
+        paths.append(path2);
+        return paths;
     }
 
     inline QStringList allOverrideDirs(const bool useAppId, const QString &prefix) const override
@@ -832,81 +868,74 @@ DConfigMetaImpl::~DConfigMetaImpl()
 }
 
 /*!
-    \class DConfigCache
+    \class Dtk::Core::DConfigCache
     \inmodule dtkcore
 
-    \brief 提供配置文件的用户和全局运行缓存访问接口
+    \brief 提供配置文件的用户和全局运行缓存访问接口.
 
 */
 
-/*
+/*!
     \fn bool DConfigCache::load(const QString &localPrefix = QString()) = 0;
-    \breaf 解析缓存配置文件
+    \brief 解析缓存配置文件
     \return
 */
 
-/*
+/*!
     \fn bool DConfigCache::save(const QString &localPrefix = QString(), QJsonDocument::JsonFormat format = QJsonDocument::Indented, bool sync = false) = 0;
-    \breaf 保存缓存的值到磁盘中
+    \brief 保存缓存的值到磁盘中
     \a localPrefix 为目录前缀
     \a format 保存格式
     \a sync 是否立即刷新
     \return
 */
 
-/*
+/*!
     \fn bool DConfigCache::isGlobal() const = 0;
     \brief 是否是全局缓存
     \return
 */
 
-/*
-    \fn void DConfigCache::resetMeta(DConfigMeta *meta) = 0;
-    \breaf 重置配置描述对象
-    \a meta 描述对象
-    \return
-*/
-
-/*
+/*!
     \fn void DConfigCache::remove(const QString &key) = 0;
-    \breaf 删除缓存中的配置项
+    \brief 删除缓存中的配置项
     \a key 配置项名称
     \return
 */
 
-/*
+/*!
     \fn QStringList DConfigCache::keyList() const = 0;
-    \breaf 返回配置内容的所有配置项
+    \brief 返回配置内容的所有配置项
     \return
 */
 
-/*
-    \fn bool DConfigCache::setValue(const QString &key, const QVariant &value, const uint uid, const QString &appid) = 0;
-    \breaf 设置缓存中的值
+/*!
+    \fn bool DConfigCache::setValue(const QString &key, const QVariant &value, const int serial, const uint uid, const QString &callerAppid) = 0;
+    \brief 设置缓存中的值
     \a key 配置项名称
     \a value 需要设置的值
     \a uid 设置时的用户id
-    \a appid 设置时的应用id
+    \a callerAppid 设置时的应用id
     \return 为true时表示重新设置了新值，false表示没有设置
 */
 
-/*
-    \fn QVariant DConfigCache::value(const QString &key) = 0;
-    \breaf 获取缓存中的值
+/*!
+    \fn QVariant DConfigCache::value(const QString &key) const = 0;
+    \brief 获取缓存中的值
     \a key 配置项名称
     \return
 */
 
-/*
+/*!
     \fn int DConfigCache::serial(const QString &key) const = 0;
-    \breaf 返回配置项的单调递增值
+    \brief 返回配置项的单调递增值
     \a key 配置项名称
     \return -1为无效值，表明没有配置此项
 */
 
-/*
+/*!
     \fn uint DConfigCache::uid() const = 0;
-    \breaf 用户标识，为全局缓存时，uid为非用户标识的特定值
+    \brief 用户标识，为全局缓存时，uid为非用户标识的特定值
     \return
 */
 
@@ -937,7 +966,7 @@ public:
         if (homePath.isEmpty()) {
             return QString();
         }
-        const QString userHomeConfigDir = homePath + QStringLiteral("/.config");
+        const QString userHomeConfigDir = homePath + QStringLiteral("/.config/dsg/configs/");
         return prefix + userHomeConfigDir + "/" + configKey.appId;
     }
 
@@ -948,11 +977,11 @@ public:
 
     inline QString globalCacheDir(const QString &prefix) const {
         // TODO `DSG_APP_DATA` is not set and `appid` is not captured in `DStandardPaths::path`.
-        if (DStandardPaths::path(DStandardPaths::DSG::AppData).isEmpty())
-            return prefix + QString("/var/dsg/appdata/%1/configs").arg(configKey.appId);
+        QString appDataDir = DStandardPaths::path(DStandardPaths::DSG::AppData);
+        if (appDataDir.isEmpty())
+            appDataDir = QString("/var/dsg/appdata");
 
-        return prefix + DStandardPaths::filePath(DStandardPaths::DSG::AppData,
-                                                 QString("configs"));
+        return QString("%1/%2/configs/%3").arg(prefix, appDataDir, configKey.appId);
     }
 
     QString getCacheDir(const QString &localPrefix = QString())
@@ -1126,7 +1155,20 @@ public:
                 cache->remove(key);
                 return true;
             } else {
-                return cache->setValue(key, value, configMeta->serial(key), cache->uid(), appid);
+                const auto &metaValue = configMeta->value(key);
+                // sample judgement to reduce a copy of convert.
+                if (metaValue.type() == value.type())
+                    return cache->setValue(key, value, configMeta->serial(key), cache->uid(), appid);
+
+                // convert copy to meta's type, it promises `setValue` don't change meta's type.
+                auto copy = value;
+                if (!copy.convert(metaValue.userType())) {
+                    qCWarning(cfLog) << "check type error, meta type is " << metaValue.type()
+                                     << ", and now type is " << value.type();
+                    return false;
+                }
+
+                return cache->setValue(key, copy, configMeta->serial(key), cache->uid(), appid);
             }
         }
         return false;
@@ -1174,14 +1216,6 @@ DConfigFilePrivate::~DConfigFilePrivate()
     }
 }
 
-/*!
-    \class DTK::Core::DConfigFile
-    \inmodule dtkcore
-
-    \brief 规范配置文件读写的相关接口的配置文件实现
-
- */
-
 /*!
     \brief 支持的版本
     \return
@@ -1215,8 +1249,8 @@ DConfigFile::DConfigFile(const DConfigFile &other)
     d->globalCache = cache;
 }
 
-/*
-    \breaf 解析配置文件
+/*!
+    \brief 解析配置文件
     \a localPrefix 为目录前缀
     \return
 */
@@ -1226,8 +1260,8 @@ bool DConfigFile::load(const QString &localPrefix)
     return d->load(localPrefix);
 }
 
-/*
-    \breaf 解析配置文件流
+/*!
+    \brief 解析配置文件流
     \a meta 为原型流
     \a overrides 为覆盖机制查找的文件流
     \return
@@ -1237,8 +1271,8 @@ bool DConfigFile::load(QIODevice *meta, const QList<QIODevice *> &overrides)
     return this->meta()->load(meta, overrides);
 }
 
-/*
-    \breaf 保存缓存的值到磁盘中
+/*!
+    \brief 保存缓存的值到磁盘中
     \a format 保存格式
     \a sync 是否立即刷新
     \return
@@ -1265,7 +1299,7 @@ QVariant DConfigFile::value(const QString &key, DConfigCache *userCache) const
 }
 
 /*!
-    \breaf 设置缓存中的值
+    \brief 设置缓存中的值
     \a key 配置项名称
     \a value 需要设置的值
     \a uid 设置时的用户id
