@@ -240,24 +240,40 @@ bool DSysInfoPrivate::ensureOsVersion()
     DDesktopEntry entry(OS_VERSION_FILE);
     bool ok = false;
 
+#define D_ASSET_EXIT(con, msg) do { \
+    if (!(con)) { \
+        qWarning() << __func__ << msg; \
+        return false; \
+    } \
+} while (false)
+
+    D_ASSET_EXIT(entry.status() == DDesktopEntry::NoError, entry.status());
+
     // 先获取版本信息
-    // ABCDE.xyz
+    // ABCDE.xyz.abc
     QString osb = entry.stringValue("OsBuild", "Version");
     QStringList osbs = osb.split(".");
-    Q_ASSERT(osbs.size() == 2 && osbs.value(0).size() == 5);
-    uint left = osbs.value(0).trimmed().toUInt(&ok);
-    Q_ASSERT(ok);
-    if (ok) {
-        osBuild.E = left % 10;
-        left /= 10;
-        osBuild.D = left % 10;
-        left /= 10;
-        osBuild.C = left % 10; // default C is 0
-        left /= 10;
-        osBuild.B = left % 10;
-        left /= 10;
-        osBuild.A = left % 10;
+    ok = (osbs.size() >= 2 && osbs.value(0).size() == 5);
+    D_ASSET_EXIT(ok, "OsBuild version invalid!");
+
+    const QStringList &left = osbs.value(0).split(QString(), QString::SkipEmptyParts);
+    D_ASSET_EXIT(left.size() == 5, "OsBuild version(ls) invalid!");
+
+    int idx = 0;
+    osBuild.A = left.value(idx++, "0").toUInt(&ok);
+    D_ASSET_EXIT(ok, "OsBuild version(A) invalid!");
+    osBuild.B = left.value(idx++, "0").toUInt(&ok);
+    D_ASSET_EXIT(ok, "OsBuild version(B) invalid!");
+    osBuild.C = left.value(idx++, "0").toUInt(&ok);
+    if (!ok) {
+        auto c = left.value(idx-1, "0").toLatin1();
+        D_ASSET_EXIT(c.size()>0, "OsBuild version(C) invalid!");
+        osBuild.C = uint(c.at(0));
     }
+    osBuild.D = left.value(idx++, "0").toUInt(&ok);
+    D_ASSET_EXIT(ok, "OsBuild version(D) invalid!");
+    osBuild.E = left.value(idx++, "0").toUInt(&ok);
+    D_ASSET_EXIT(ok, "OsBuild version(E) invalid!");
 
     // xyz
     osBuild.xyz = osbs.value(1).trimmed().toUInt(&ok);
@@ -786,8 +802,9 @@ QString DSysInfo::minorVersion()
  */
 QString DSysInfo::buildVersion()
 {
-    siGlobal->ensureOsVersion();
-    return QString::number(siGlobal->osBuild.xyz);
+    DDesktopEntry entry(OS_VERSION_FILE);
+    QString osb = entry.stringValue("OsBuild", "Version");
+    return osb.mid(6).trimmed();
 }
 #endif
 
