@@ -18,7 +18,6 @@
 #pragma once
 
 #include <QtCore/qglobal.h>
-
 #include <dtkcore_config.h>
 
 #define DTK_NAMESPACE Dtk
@@ -67,3 +66,8 @@
 
 #define DTK_VERSION_CHECK(major, minor, patch, build) ((major<<24)|(minor<<16)|(patch<<8)|build)
 #define DTK_VERSION DTK_VERSION_CHECK(DTK_VERSION_MAJOR, DTK_VERSION_MINOR, DTK_VERSION_PATCH, DTK_VERSION_BUILD)
+
+extern "C" {
+int LIBDTKCORESHARED_EXPORT dtkVersion();
+const LIBDTKCORESHARED_EXPORT char *dtkVersionString();
+}
