@@ -2,7 +2,7 @@
  * Copyright (C) 2017 ~ 2017 Deepin Technology Co., Ltd.
  *
  * This program is free software: you can redistribute it and/or modify
- * it under the terms of the GNU General Public License as published by
+ * it under the terms of the GNU Lesser General Public License as published by
  * the Free Software Foundation, either version 3 of the License, or
  * any later version.
  *
@@ -11,12 +11,29 @@
  * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
  * GNU General Public License for more details.
  *
- * You should have received a copy of the GNU General Public License
+ * You should have received a copy of the GNU Lesser General Public License
  * along with this program.  If not, see <http://www.gnu.org/licenses/>.
  */
 
-#include <QtTest/QtTest>
+#include "ut_dutil.h"
+#include <QGuiApplication>
 
-#include "dutiltester.h"
+#ifdef QT_DEBUG
+#include <sanitizer/asan_interface.h>
+#endif
 
-QTEST_MAIN(TestDUtil);
+int main(int argc, char *argv[])
+{
+    QCoreApplication app(argc, argv);
+
+    DTimedLoop loop;
+
+    testing::InitGoogleTest(&argc, argv);
+    int retVal = RUN_ALL_TESTS();
+
+#ifdef QT_DEBUG
+    __sanitizer_set_report_path("asan.log");
+#endif
+
+    return loop.exec(0, "main execution") + retVal;
+}
